@@ -74,11 +74,18 @@ cch <- function(formula, data=sys.parent(), subcoh, id, stratum=NULL, cohort.siz
     X <- model.matrix(Terms, m)
     X <- X[,2:ncol(X)]
     fitter <- get(method)
+
+    # The artificial offset is 1/2 the minimal distance between events
+    if (ncol(Y)==3) dtime <- unique(Y[cens==1,2])
+    else dtime <- unique(Y[cens, 1])
+    delta <- min(diff(sort(dtime))) /2
+    
     if (stratified)        
         out<-fitter(tenter=tenter, texit=texit, cc=cc, id=id, X=X,
-                    stratum=as.numeric(stratum), stratum.sizes=cohort.size)
+                    stratum=as.numeric(stratum), stratum.sizes=cohort.size,
+                    eps=delta)
     else
-        out<-fitter(tenter=tenter, texit=texit, cc=cc, id=id, X=X, ntot=nn, robust=robust)
+        out<-fitter(tenter=tenter, texit=texit, cc=cc, id=id, X=X, ntot=nn, robust=robust, eps = delta)
     out$method <- method
     names(out$coefficients) <- dimnames(X)[[2]]
     if(!is.null(out$var))
@@ -100,15 +107,14 @@ cch <- function(formula, data=sys.parent(), subcoh, id, stratum=NULL, cohort.siz
 
 ### Subprograms
 
-Prentice <- function(tenter, texit, cc,  id, X, ntot,robust){
-    eps <- 0.00000001
+Prentice <- function(tenter, texit, cc,  id, X, ntot,robust, eps){
     cens <- as.numeric(cc>0) # Censorship indicators
     subcoh <- as.numeric(cc<2) # Subcohort indicators
 
     ## Calculate Prentice estimate
     ent2 <- tenter
     ent2[cc==2] <- texit[cc==2]-eps
-    fit1 <- coxph(Surv(ent2,texit,cens)~X,eps=eps,x=TRUE)
+    fit1 <- coxph(Surv(ent2,texit,cens)~X,eps=eps,x=TRUE, timefix=FALSE)
 
     ## Calculate Prentice estimate and variance
     nd <- sum(cens) # Number of failures
@@ -124,7 +130,7 @@ Prentice <- function(tenter, texit, cc,  id, X, ntot,robust){
     gp <- rep(1,nd)
     gp <- c(gp,rep(0,nc))
     fit <- coxph(Surv(aent,aexit,gp)~aX+offset(dum)+cluster(aid),eps=eps,x=TRUE,
-                 iter.max=35,init=fit1$coefficients)
+                 iter.max=35,init=fit1$coefficients, timefix=FALSE)
     db <- resid(fit,type="dfbeta")
     db <- as.matrix(db)
     db <- db[gp==0,]
@@ -136,8 +142,7 @@ Prentice <- function(tenter, texit, cc,  id, X, ntot,robust){
     fit
 }
 
-SelfPrentice <- function(tenter, texit, cc,  id, X, ntot,robust){
-    eps <- 0.00000001
+SelfPrentice <- function(tenter, texit, cc,  id, X, ntot,robust, eps){
     cens <- as.numeric(cc>0) # Censorship indicators
     subcoh <- as.numeric(cc<2) # Subcohort indicators
 
@@ -154,7 +159,8 @@ SelfPrentice <- function(tenter, texit, cc,  id, X, ntot,robust){
     dum <- c(dum,rep(0,nc))
     gp <- rep(1,nd)
     gp <- c(gp,rep(0,nc))
-    fit <- coxph(Surv(aent,aexit,gp)~aX+offset(dum)+cluster(aid),eps=eps,x=TRUE)
+    fit <- coxph(Surv(aent,aexit,gp)~aX+offset(dum)+cluster(aid),eps=eps,
+                 x=TRUE, timefix=FALSE)
     db <- resid(fit,type="dfbeta")
     db <- as.matrix(db)
     db <- db[gp==0,,drop=FALSE]
@@ -164,8 +170,7 @@ SelfPrentice <- function(tenter, texit, cc,  id, X, ntot,robust){
     fit
 }
 
-LinYing <- function(tenter, texit, cc,  id, X, ntot,robust){
-    eps <- 0.000000001
+LinYing <- function(tenter, texit, cc,  id, X, ntot,robust, eps){
     cens <- as.numeric(cc>0) # Censorship indicators
     subcoh <- as.numeric(cc<2) # Subcohort indicators
     nd <- sum(cens) # Number of failures
@@ -177,7 +182,7 @@ LinYing <- function(tenter, texit, cc,  id, X, ntot,robust){
     offs[cc>0] <- 1
     loffs <- log(offs)
     fit <- coxph(Surv(tenter, texit, cens)~X+offset(loffs)+cluster(id),
-                 eps=eps,x=TRUE)
+                 eps=eps,x=TRUE, timefix=FALSE)
     db <- resid(fit,type="dfbeta")
     db <- as.matrix(db)
     db0 <- db[cens==0,,drop=FALSE]
@@ -192,8 +197,7 @@ LinYing <- function(tenter, texit, cc,  id, X, ntot,robust){
     fit
 }
 
-I.Borgan <- function(tenter, texit, cc,  id, X, stratum, stratum.sizes){
-  eps <- 0.00000001
+I.Borgan <- function(tenter, texit, cc,  id, X, stratum, stratum.sizes, eps){
   nobs <- length(texit)
   idx <- 1:length(nobs)
   jj <- max(stratum)
@@ -224,7 +228,7 @@ I.Borgan <- function(tenter, texit, cc,  id, X, stratum, stratum.sizes){
   gp <- c(gp, rep(0, nc))
   w[gp==1] <- 1
   fit <- coxph(Surv(ent,exit,gp)~X+offset(dum)+cluster(id),
-               weights=w, eps=eps,x=T, iter.max=25)  
+               weights=w, eps=eps,x=T, iter.max=25, timefix=FALSE)  
   score <- resid(fit, type = "score", weighted=F)
   sc <- resid(fit, type="score", collapse=id, weighted=T)
   score <- as.matrix(score)
@@ -255,8 +259,7 @@ I.Borgan <- function(tenter, texit, cc,  id, X, stratum, stratum.sizes){
   fit
 }
 
-II.Borgan <- function(tenter, texit, cc,  id, X, stratum, stratum.sizes){
-  eps <- 0.00000001
+II.Borgan <- function(tenter, texit, cc,  id, X, stratum, stratum.sizes, eps){
   jj <- max(stratum)
   nn <- stratum.sizes  ## Cohort stratum sizes
   n <- table(stratum)  ## Sample stratum sizes
@@ -276,7 +279,7 @@ II.Borgan <- function(tenter, texit, cc,  id, X, stratum, stratum.sizes){
   w <- wt[stratum]
   w[cens==1] <- 1
   fit <- coxph(Surv(tenter,texit,cens)~X+cluster(id),
-               weights=w,eps=eps,x=T, iter.max=25)  ## Borgan Estimate II
+               weights=w,eps=eps,x=T, iter.max=25, timefix=FALSE)  ## Borgan Estimate II
   score <- resid(fit, type = "score", weighted=F)
   sc <- resid(fit,type="score", collapse=id, weighted=T)
   score <- as.matrix(score)
