@@ -670,156 +670,7 @@ static void cmatrix_free(double **data) {
     Free(data);
     }
 
-
-void agfit5c(Sint *nusedx, Sint *nvar, Sint *strata,
-	      Sint *methodx, double *expect) {
-    int i, j, k, ksave;
-    int p, istrat, indx2;
-    double denom, e_denom;
-    int deaths;
-    double hazard, e_hazard, cumhaz;
-    double temp, time;
-    double wtsum, *dtimes, *haz;
-    int nused, ndeath, method;
-    int person;
-    int strata_start;
-
-
-    nused = *nusedx;
-    method= *methodx;
-
-    j=0;
-    for (i=0; i<nused; i++) {
-	j += event[i];  /* count number of deaths */
-	expect[i] =0;   /* initialize */
-	score[i] = exp(score[i]);
-	}
-    haz = (double *) ALLOC(2*j, sizeof(double));
-    dtimes = haz +j;   
-
-    indx2 =0;
-    denom =0;
-    istrat=0;
-    ndeath = 0;
-    strata_start =0;
-    cumhaz=0;
-    for (person=0; person<nused;) {
-        p = sort1[person];
-        if (event[p]==0) { /* censored observation, just add to the denom */
-            denom += score[p]*weights[p];
-            person++;
-            }
-
-        else {
-	    /* a death found -- increment the hazard */
-            e_denom =0;
-            wtsum =0;
-            time = stop[p];
-            deaths=0;                   /* # tied deaths at this time */
-            for (k=person; k<strata[istrat]; k++) {
-                p = sort1[k];
-                if (stop[p] < time) break;
-                denom += score[p] * weights[p];
-                if (event[p]==1) {
-                    deaths += 1;
-                    e_denom += score[p]*weights[p];
-                    wtsum += weights[p];
-                    }
-                }
-            ksave = k;
-
-            /*
-            ** subtract out the subjects whose start time is to the right
-            */
-            for (; indx2<strata[istrat]; indx2++) {
-                p = sort2[indx2];
-                if (start[p] < time) break;
-                denom -= score[p] * weights[p];
-                }
-
-            /*
-            ** At this point denom, e_denom, etc are updated.  They are
-            **   used to create the increment to the hazard:
-            **   hazard = usual increment
-            **   e_hazard = efron increment, for tied deaths only
-            */
-            hazard =0;
-            e_hazard=0;
-            wtsum /=deaths;
-            for (k=0; k<deaths; k++) {
-                temp = method *(k/(double) deaths);
-                hazard   += wtsum/(denom - temp*e_denom);
-                e_hazard += wtsum*(1-temp)/(denom - temp*e_denom);
-                }
-	    cumhaz += hazard;
-            dtimes[ndeath] = time;      /* remember the death times */
-            haz[ndeath] =    cumhaz;
-	    ndeath++;
-
-            /*
-            ** Add this hazard increment to all whose intervals end just now
-            */
-            for (k=person-1; k>=strata_start; k--) { /*non-deaths */
-                p = sort1[k];
-                if (stop[p] > time) break;
-                expect[p] += score[p]*hazard;
-                }
-            for (; person<ksave; person++) { /* deaths */
-                p = sort1[person];
-                expect[p] += score[p]*e_hazard;
-                }
-            }
-            
-        if (person==strata[istrat]) {
-	    /*
-            ** Last subject of a stratum.  Do the remaining work.
-            ** Walk through the list of subjects, adding in the
-            **  accrued hazard at non-death times (times strictly inside
-            **  each subject's interval).
-	    ** We use the difference in cumulate hazards, to keep the process
-	    **  to O(2n) rather than O(n * ndeath)
-	    */
-	    i = strata_start;
-	    temp =0;
-	    for (k=0; k<ndeath; k++) {
-		for (; i<person; i++) {
-		    p = sort2[i];
-		    if (start[p] >= dtimes[k]) expect[p] += temp;
-		    else break;
-		    }
-		temp = haz[k];
-		}
-	    for (; i<person; i++) {  /*those entered before the first death */
-		p = sort2[i];
-		expect[p] += score[p]*temp;
-		}
-
-	    /* Now subtract the cumhaz at lower interval */
-	    i = strata_start;
-	    temp =0;
-	    for (k=0; k<ndeath; k++) {
-		for (; i<person; i++) {
-		    p = sort1[i];
-		    if (stop[p] > dtimes[k]) expect[p] -= score[p]*temp;
-		    else break;
-		    }
-		temp = haz[k];
-		}
-	    for (; i<person; i++) {  /* those exiting <= the first death */
-		p = sort1[i];
-		expect[p] -= score[p]*temp;
-		}
-	    
-	    /* reset for the next stratum */
-            istrat++;
-            denom=0;
-	    cumhaz=0;
-            ndeath=0;
-            indx2 =  person;
-            strata_start=person;
-            }
-        }
-    
+void agfit5c(Sint *nvar) {
     /*
     ** Free up the extra memory
     */
